Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/richdocuments.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/file.php')
-rw-r--r--lib/file.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/file.php b/lib/file.php
index fb6ae9fb..4668e569 100644
--- a/lib/file.php
+++ b/lib/file.php
@@ -1,6 +1,6 @@
<?php
/**
* ownCloud - Documents App
*
* @author Victor Dubiniuk
* @copyright 2013 Victor Dubiniuk victor.dubiniuk@gmail.com
@@ -20,7 +20,7 @@
*
*/
-namespace OCA\Documents;
+namespace OCA\Richdocuments;
use \OC\Files\View;
@@ -190,7 +190,7 @@ class File {
$mimetype = $this->ownerView->getMimeType($this->path);
if (!Filter::isSupportedMimetype($mimetype)){
- throw new \Exception( $this->path . ' is ' . $mimetype . ' and is not supported by Documents app');
+ throw new \Exception( $this->path . ' is ' . $mimetype . ' and is not supported by RichDocuments app');
}
}
@@ -1,6 +1,6 @@
<?php
/**
- * ownCloud - Documents App
+ * ownCloud - Richdocuments App
*
* @author Victor Dubiniuk